@@ -53,6 +53,10 @@ class Helper(object):
         }
         if NEED_COW:
             dm_path += '-cow'
+        # check if path exists
+        if not os.path.exists(dm_path):
+            print 'Couldn\'t find device-mapper path: %s' % dm_path
+            sys.exit(1)
         return dm_path
 
     def find_diff_map(self, snapshot):
@@ -143,9 +147,9 @@ class MainHandler(object):
             'remote': dst_volume
         }
         # if need send snapshot to remote server (vm can be running)
-        print 'First need to send created snapshot to remote server.'
-        print 'Type \'no\' if you has already sent volume manually).'
-        print 'Command: \033[1;32m%s\033[1;m' % sync_command
+        print 'At first you need to send created snapshot to remote server.'
+        print 'Type \'no\' if you has already sent volume manually.'
+        print 'Command: \033[1;32m%s\033[1;m' % sync_command    
         SEND_SNAPSHOT = raw_input('Run sync? [yes/no]: ')
 
         if SEND_SNAPSHOT == 'yes':
@@ -198,4 +202,4 @@ if __name__ == '__main__':
             print 'Usage: lvsync /dev/<vg>/<snap-name> root@<server>:/dev/<vg>/<lv-name>'
             sys.exit(1)
         # client mode
-        main.client()
\ No newline at end of file
+        main.client()
